@@ -1,6 +1,6 @@
 from abc import ABC
 
-from dt_duckiematrix_protocols.types import EngineMode
+from dt_duckiematrix_types import EngineMode
 from dt_duckiematrix_protocols.commons.CBORProtocol import CBORProtocol
 
 
